pub struct SolInput {
pub attrs: Vec<Attribute>,
pub path: Option<PathBuf>,
pub kind: SolInputKind,
}Expand description
Parsed input for sol!-like macro expanders. This struct represents a list
of expandable items parsed from either solidity code snippets, or from a
JSON abi.
Fields
attrs: Vec<Attribute>Attributes attached to the input, of the form #[...].
path: Option<PathBuf>Path to the input, if any.
kind: SolInputKindThe input kind.
Implementations